@@ -27,26 +27,30 @@
 
 #include <KDEDModule>
 
-#include "plasmanm_export.h"
-
 #include <QVariant>
 
 class NetworkManagementServicePrivate;
 
-class PLASMA_NM_EXPORT NetworkManagementService : public KDEDModule
+class Q_DECL_EXPORT NetworkManagementService : public KDEDModule
 {
+    Q_CLASSINFO("D-Bus Interface", "org.kde.plasmanetworkmanagement")
     Q_OBJECT
     Q_DECLARE_PRIVATE(NetworkManagementService)
 public:
     NetworkManagementService(QObject * parent, const QVariantList&);
     virtual ~NetworkManagementService();
+
 public Q_SLOTS:
-    void doInitializeNotifications();
+    Q_SCRIPTABLE void init();
+
+Q_SIGNALS:
+    Q_SCRIPTABLE void registered();
+
+private Q_SLOTS:
+    void slotRegistered(const QDBusObjectPath &path);
 
 private:
-    NetworkManagementServicePrivate * d_ptr;
-
-    void initializeNotifications();
+    NetworkManagementServicePrivate * const d_ptr;
 };
 
 #endif // PLASMANM_KDED_SERVICE_H
